{% extends 'portal/base.html' %}
{% load static %}
{% load app_tags banner_tags hero_card_tags card_list_tags character_list_tags %}

{% block subNav %}
<section class="banner banner--aimmo">
    <img title="Kurono logo" alt="Kurono logo" src="{% static 'portal/img/kurono_logo.svg' %}">
</section>
{% endblock subNav %}

{% block content %}
{% if not user|is_independent_student %}
    {% if HERO_CARD %}
        <div class="background container">
            {% hero_card hero_card_name="HERO_CARD" %}
        </div>

        <div class="container carousel-cards-container">
            {% card_list %}
        </div>
    {% else %}
        <div class="background text-center container">
            <h4>My Games</h4>
            <p>
                Oh no! It doesn't look like you have access to any games, yet. You'll need to ask your teacher to set
                some up.
            </p>
        </div>
    {% endif %}

    <div class="background background--primary">
        <div class="container">
            {% character_list %}
        </div>
    </div>
{% else %}
    <div class="background text-center container">
        <h4>My Games</h4>
        <p>
            Hi there! 👋 We are sorry, but Kurono is designed to be used in a classroom, and therefore it is not
            available to independent students at this time.
        </p>
    </div>
{% endif %}

{% endblock content %}
