{% extends 'portal/base.html' %}
{% load static %}
{% load app_tags %}
{% load banner_tags %}

{% block subNav %}
{% banner banner_name="BANNER" %}
{% endblock subNav %}

{% block content %}
<div class="background container">
    <section>
        <h4>How to get involved and gain experience</h4>
    </section>
        <div class="row">
            <div class="col-sm-6">
                <p>Code for Life would not have been possible without the dedication of our volunteers.
                </p>
                <p>In 2014, computing was added to the UK curriculum, requiring schools to teach coding
                principles and programming foundations.
                </p>
            </div>
            <div class="col-sm-6">
                <p>Recognising a need to support teachers and students in navigating the uncharted territory,
                Ocado Technology deployed an army of internal volunteers who worked after hours, fuelled by
                free pizzas and fizzy drinks.
                </p>
                <p>What came out of this, is what you see today, used by educators and learners from over 150
                countries. Our products are open-source and free forever.
                </p>
            </div>
        </div>
        <div class="text-right">
            <a href="https://docs.codeforlife.education/" target="_blank" class="button button--primary button-right-arrow">
                Read our developer guide
            </a>
        </div>
    </div>
</div>

<div class="background background--primary">
    <div class="row">
        <div class="container d-flex flex-row">
            <div class="col-sm-6">
                <h4>Our products</h4>

                <p><b>The portal or website</b></p>
                <p>This is the gateway for users to get to know who we are and what we do.
                It hosts our web-based games and plenty of teaching resources.
                </p>

                <p><b>Rapid Router</b></p>
                <p>An introduction to coding that is aimed at Key Stages 1-3 (age 5 to 14).
                Built on Blockly, it's a visual programming language similar to Scratch.
                The levels start off with Blockly and gradually progress to Python. With 109 levels,
                Rapid Router is our flagship game with the biggest user base.
                </p>

                <p><b>Kurono</b></p>
                <p>A multiplayer game that is aimed at older students of Key Stages 3 and up,
                it is primarily for use in a class or a club setting. Students code in Python to
                move their avatar around in order to complete tasks. Parts of Kurono are still in development.
                </p>
            </div>
            <div class="col-sm-6">
                <img title="Rapid Router" alt="Rapid Router" src="{% static 'portal/img/rapidrouter.png' %}">
            </div>
        </div>
    </div>
</div>

<div class="background container">
    <div class="row">
        <div class="col-sm-6 bg-image">
            <img title="Gitbook" alt="Gitbook" src="{% static 'portal/img/gitbook.png' %}" class="img-border">
        </div>
        <div class="col-sm-6">
            <h4>How you can contribute</h4>
            <p>Today, there is a small dedicated team working full time on Code for Life.
            In 2021, we're expecting to reach over 100,000 newly registered teachers and students.
            We need your help to do even more.
            </p>
            <p>
            If contributing to open-source projects to support education in coding and technology
            sounds exciting for you, we'd love to have you on board!
            </p>
            <div class="text-right">
                <a href="https://docs.codeforlife.education/" target="_blank" class="button button--primary button-right-arrow">
                    Read our developer guide
                </a>
            </div>
        </div>
    </div>
</div>

{% endblock content %}
