{% extends 'portal/form_shapes.html' %}
{% load static %}

{% block form_content %}
    <div id="reset_password_email_sent_page"></div>
    <h4>Thank you</h4>
    <img class="background" title="Paper Plane" alt="Verification email sent" src="{% static 'portal/img/paper_plane.png' %}">
    <p class="text-left">If you have entered a valid email address, you will receive 
        a link enabling you to reset your password.</p>
    <div>
        {% if usertype == "TEACHER" %}
            <a href="{% url 'home' %}" class="button button--primary button--login">Back to homepage</a>
        {% else %}
            <a href="{% url 'home' %}" class="button button--home">Back to homepage</a>
        {% endif %}
    </div>
{% endblock form_content %}
