@import 'base';

.video--aimmo--play-online {
  margin-top: 4 * $spacing;
  padding-left: 0px;
  padding-right: 0px;
  -webkit-box-shadow: 0px 4px 18px 0px $color-ui-widget-overlay;
  -moz-box-shadow: 0px 4px 18px 0px $color-ui-widget-overlay;
  box-shadow: 0px 4px 18px 0px $color-ui-widget-overlay;
}
