AIMMO_DASHBOARD_BANNER = {
    "title": "Kurono dashboard",
    "subtitle": "Let the adventures begin! A collection of challenges await your "
    "exploration. See how far you can get.",
    "image_class": "banner--picture--aimmo",
}
