{% extends 'portal/base.html' %}
{% load static %}
{% load app_tags %}
{% load banner_tags %}

{% block subNav %}
{% banner banner_name="BANNER" %}
{% endblock subNav %}

{% block content %}
<div class="background container">
    <section>
        <h4>Code For Life is a non profit initiative that delivers free, open-source games that help all students learn
            computing.</h4>
        <div class="row homepage-info">
            <div class="col-sm-4">
                <h2 class="text--brand-tertiary">2014</h2>
                <p>The year that computing was added to the UK curriculum. We've been supporting teachers and students
                ever since.</p>
            </div>
            <div class="col-sm-4">
                <h2 class="text--brand-tertiary">>160</h2>
                <p>Countries are taking part, with the UK, the USA, Brazil, Australia and Canada as top locations for
                schools signed up to CFL. Nearly 10,000 schools are registered globally.</p>
            </div>
            <div class="col-sm-4">
                <h2 class="text--brand-tertiary">>270,000</h2>
                <p>Active users so far, with numbers growing every day. In 2020 alone, close to 100,000 new people
                subscribed to our resources.</p>
            </div>
        </div>
    </section>
</div>
<div class="background background--primary">
    <div class="container">
        <div class="row d-flex align-items-center">
            <div class="col-sm-6">
                <h5>What is Code for Life?</h5>
                <p>Code for Life (CFL) is a free, easy-to-use resource that provides teaching and lesson plans, user
                    guides and engagement through our two fun coding games: Rapid Router and Kurono. These games are
                    specially designed for people learning computing for the first time.</p>
                <p>The aim is to teach new coders the basic principles, to help them thrive in an increasingly digital
                    world. CFL is primarily designed for and tested by primary school teachers. Our games are aligned
                    with the UK's computing curriculum, so teachers can incorporate CFL into their lessons.</p>
                <p>Anyone looking to get into coding can also do so using the games and resources. We opened CFL
                    resources to parents and the general public during the 2020 Covid-19 pandemic so that people
                    don't need to be part of a school to have access.</p>
            </div>
            <div class="col-sm-6">
                <img title="What is Code for Life?" alt="What is Code for Life?" src="{% static 'portal/img/about_us_cfl.jpg' %}">
            </div>
        </div>
    </div>
</div>
<div class="background container">
    <div class="row d-flex align-items-center">
        <div class="col-sm-6">
            <img title="Who is Ocado Group?" alt="Who is Ocado Group?" src="{% static 'portal/img/about_us_ocado.jpg' %}">
        </div>
        <div class="col-sm-6">
            <h5>Who is Ocado Group?</h5>
            <p>Ocado Group, the online grocery solutions provider, is powering the future of online retail. Ocado's
                tech and solutions are supplied to grocery businesses all around the world. It enables these
                forward-thinking retailers to do grocery online profitably, sustainably, and in a scalable manner.</p>
            <p>The Ocado Smart Platform (OSP) is the world's most advanced end-to-end e-Commerce, fulfilment and
                logistic platform.</p>
            <p><a target="_blank" href="https://www.ocadogroup.com/our-responsible-business/corporate-responsibility/skills-for-the-future">
                Skills for the Future</a> is one of Ocado Group's core Corporate Responsibility pillars, which is
                part of the Ocado Unlimited strategy (alongside Natural Resources and Responsible Sourcing). For Ocado
                Group, Skills for the Future means championing digital literacy. We want to inspire the next generation
                of STEM leaders, so that everyone can fully participate in society.</p>
        </div>
    </div>
</div>
<div class="background background--primary">
    <div class="container">
        <section><h4>Code for Life and Ocado Group</h4></section>
        <div class="row">
            <div class="col-sm-6">
                <blockquote>
                    <p class="says text--brand-primary">
                        “We were delighted computing entered the UK curriculum in 2014. However, many teachers felt
                        unprepared. And the lack of diversity in people studying STEM concerned us. So, we sought to
                        make the subject appeal to a broader group of both students and teachers."
                    </p>
                </blockquote>
                <p>Anne Marie Neatham, Commercial Director and COO Kindred, Ocado Group.</p>
            </div>
            <div class="col-sm-6">
                <p>With that in mind, CFL was developed by volunteers and interns from Ocado Technology - the
                technology arm of Ocado Group - and teacher Sharon Harrison, who created the Rapid Router learning
                materials. Anne Marie continues:</p>
                <blockquote>
                    <p class="says text--brand-primary">
                        “I'm proud this initiative has been breaking down stereotypes. Children are seeing that you
                        don't have to fit a certain gender, race or personality type to get coding."
                    </p>
                </blockquote>
                <p>Today, CFL is operated by a small core team and volunteers.</p>
            </div>
        </div>
    </div>
</div>

<div class="background container">
    <section><h4>We couldn't do it without you!</h4></section>
    <div class="row">
        <div class="col-sm-6">
            <h5>Our team and volunteers</h5>
            <p>Code for Life would not have been possible without the time and skills volunteered by our talented
                developers and creatives at Ocado Technology. Thank you to everyone who has helped us get to where
                we are now.</p>
            <h5>Want to get involved?</h5>
            <p>We are open source, so anyone can ask to contribute. You can play with game-running JavaScript,
                Python/Django, animation using SVG and Raphael, and a lot more. We'd like input from all sorts of
                backgrounds, whether you're: a programmer looking for a creative outlet; a teacher hoping to shape
                the resources; or even a pupil putting your skills to the test.</p>
        </div>
        <div class="col-sm-6">
            <h5>Developers</h5>
            <p>To contribute, head over to <a target="_blank" href="https://github.com/ocadotechnology/codeforlife-portal">GitHub</a>,
                check out the issue tracker, and get started. There you can suggest new features or assign yourself
                an issue to develop. You can find more info about how to do all these on our 
                <a target="_blank" href="https://docs.codeforlife.education/">docs on Gitbook</a>.
            <h5>Teachers, parents, and creatives</h5>
            <p>Please get in touch through our <a class="freshdesk__contact-us">contact</a> form and let us know how
                you would like to get involved.</p>
            <p>We would like to thank our friends who have contributed to this initiative.</p>
        </div>
    </div>
    <section class="background">
        <h6>We would like to thank our friends who have contributed to this initiative</h6>
        <div class="row image-row">
            <img title="10x" alt="10x logo" src="{% static 'portal/img/10x_logo.png' %}">
            <img title="BCS" alt="BCS logo" src="{% static 'portal/img/bcs_logo.png' %}">
            <img title="ICL" alt="Imperial logo" src="{% static 'portal/img/icl_logo.png' %}">
            <img title="Barefoot" alt="Barefoot logo" src="{% static 'portal/img/barefoot_logo.png' %}">
            <img title="MC Saatchi" alt="MC Saatchi logo" src="{% static 'portal/img/mc_saatchi_logo.png' %}">
            <img title="HOPE" alt="HOPE logo" src="{% static 'portal/img/hope_logo.png' %}">
            <img title="GLA" alt="GLA logo" src="{% static 'portal/img/gla_logo.png' %}">
            <img title="Pressure Cooker" alt="Pressure Cooker logo" src="{% static 'portal/img/pressure_cooker_logo.png' %}">
        </div>
        <p><small>10X, BCS Academy of Computing, Barefoot Computing, Computing at School, The National Museum of
            Computing, Imperial College London, M&C Saatchi, Alvaro Ramirez, Jason Fingland, Ramneet Loyall, Sharon
            Harrison, Keith Avery, Dale Coan, Rob Whitehouse, Mandy Nash, Tanya Nothard, Matt Trevor, Moy El-Bushra,
            Richard Siwiak, Peter Tondrow, Liz Pratt, Pressure Cooker Studios, GAL Education, Hope Education.</small></p>
    </section>
</div>

<div class="background background--primary">
    <div class="container">
        <section>
            <h4>Dedicated to Sharon Harrison</h4>
            <img title="Sharon Harrison" alt="Sharon Harrison portrait" class="portrait" src="{% static 'portal/img/sharon_harrison.jpg' %}">
            <h5>1956 &mdash; 2015</h5>
        </section>
        <p><strong>Sharon was instrumental in helping to create Code for Life. At the beginning of 2014 she was
            recruited to act as our Educational Consultant. The project drew on her previous skills as a pioneering
            computing teacher and education consultant.</strong></p>
        <p>Sharon has left a lasting legacy by creating something which will help teach STEM skills to the next
            generation of computer scientists across the world.</p>
    </div>
</div>
{% endblock content %}
