{# Overriding the original "two_factor" template #}

{% extends "two_factor/_base_focus.html" %}
{% load i18n %}

{% block content %}
    <h4 class="text-center">{% block title %}{% trans "Two-factor authentication" %}{% endblock %}</h4>
    {% if wizard.steps.current == 'welcome' %}
        <p>{% blocktrans trimmed %}You are about to take your account security to the
            next level. Follow the steps in this wizard to enable two-factor
            authentication.{% endblocktrans %}</p>
    {% elif wizard.steps.current == 'method' %}
        <p>{% blocktrans trimmed %}Please select which authentication method you would
            like to use.{% endblocktrans %}</p>
    {% elif wizard.steps.current == 'generator' %}
        <p>{% blocktrans trimmed %}Two-factor authentication is not currently set up on your account.
            Enable two-factor authentication (2FA) for enhanced account security
        {% endblocktrans %}</p>
        <p>{% blocktrans trimmed %}To start using a token generator, please use your
            smartphone to scan the QR code below. For example, use Google
            Authenticator.
        {% endblocktrans %}</p>
        <p><img src="{% url 'two_factor:qr' %}" alt="QR Code" /></p>
    {% elif wizard.steps.current == 'sms' %}
        <p>{% blocktrans trimmed %}Please enter the phone number you wish to receive the
            text messages on. This number will be validated in the next step.
        {% endblocktrans %}</p>
    {% elif wizard.steps.current == 'call' %}
        <p>{% blocktrans trimmed %}Please enter the phone number you wish to be called on.
            This number will be validated in the next step. {% endblocktrans %}</p>
    {% elif wizard.steps.current == 'validation' %}
        {% if challenge_succeeded %}
            {% if device.method == 'call' %}
                <p>{% blocktrans trimmed %}We are calling your phone right now, please enter the
                    digits you hear.{% endblocktrans %}</p>
            {% elif device.method == 'sms' %}
                <p>{% blocktrans trimmed %}We sent you a text message, please enter the tokens we
                    sent.{% endblocktrans %}</p>
            {% endif %}
        {% else %}
            <p class="alert alert-warning" role="alert">{% blocktrans trimmed %}We've
                encountered an issue with the selected authentication method. Please
                go back and verify that you entered your information correctly, try
                again, or use a different authentication method instead. If the issue
                persists, contact the site administrator.{% endblocktrans %}</p>
        {% endif %}
    {% elif wizard.steps.current == 'yubikey' %}
        <p>{% blocktrans trimmed %}To identify and verify your YubiKey, please insert a
            token in the field below. Your YubiKey will be linked to your
            account.{% endblocktrans %}</p>
    {% endif %}

    <form action="" method="post">{% csrf_token %}
        {% include "two_factor/setup_wizard_token.html" %}
        {% include "two_factor/_wizard_actions_enable_2fa.html" %}
    </form>
{% endblock %}
